==> kubernetes-model-admissionregistration-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1/MutatingWebhookConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface MutatingWebhookConfigurationFluent<A extends MutatingWebhookConfigurationFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadata();
  public MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public MutatingWebhookConfigurationFluent.MetadataNested<A> editMetadata();
  public MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadata();
  public MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public A addToWebhooks(Integer index,MutatingWebhook item);
  public A setToWebhooks(Integer index,MutatingWebhook item);
  public A addToWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhook... items);
  public A addAllToWebhooks(Collection<MutatingWebhook> items);
  public A removeFromWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhook... items);
  public A removeAllFromWebhooks(Collection<MutatingWebhook> items);
  public A removeMatchingFromWebhooks(Predicate<MutatingWebhookBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildWebhooks instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<MutatingWebhook> getWebhooks();
  public List<MutatingWebhook> buildWebhooks();
  public MutatingWebhook buildWebhook(Integer index);
  public MutatingWebhook buildFirstWebhook();
  public MutatingWebhook buildLastWebhook();
  public MutatingWebhook buildMatchingWebhook(Predicate<MutatingWebhookBuilder> predicate);
  public Boolean hasMatchingWebhook(Predicate<MutatingWebhookBuilder> predicate);
  public A withWebhooks(List<MutatingWebhook> webhooks);
  public A withWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhook... webhooks);
  public Boolean hasWebhooks();
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhook();
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhookLike(MutatingWebhook item);
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> setNewWebhookLike(Integer index,MutatingWebhook item);
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> editWebhook(Integer index);
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> editFirstWebhook();
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> editLastWebhook();
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> editMatchingWebhook(Predicate<MutatingWebhookBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<MutatingWebhookConfigurationFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface WebhooksNested<N> extends Nested<N>,MutatingWebhookFluent<MutatingWebhookConfigurationFluent.WebhooksNested<N>>{
    public N and();
    public N endWebhook();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1/MutatingWebhookConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface MutatingWebhookConfigurationFluent<A extends MutatingWebhookConfigurationFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadata();
  public MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public MutatingWebhookConfigurationFluent.MetadataNested<A> editMetadata();
  public MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadata();
  public MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public A addToWebhooks(int index,MutatingWebhook item);
  public A setToWebhooks(int index,MutatingWebhook item);
  public A addToWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhook... items);
  public A addAllToWebhooks(Collection<MutatingWebhook> items);
  public A removeFromWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhook... items);
  public A removeAllFromWebhooks(Collection<MutatingWebhook> items);
  public A removeMatchingFromWebhooks(Predicate<MutatingWebhookBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildWebhooks instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<MutatingWebhook> getWebhooks();
  public List<MutatingWebhook> buildWebhooks();
  public MutatingWebhook buildWebhook(int index);
  public MutatingWebhook buildFirstWebhook();
  public MutatingWebhook buildLastWebhook();
  public MutatingWebhook buildMatchingWebhook(Predicate<MutatingWebhookBuilder> predicate);
  public Boolean hasMatchingWebhook(Predicate<MutatingWebhookBuilder> predicate);
  public A withWebhooks(List<MutatingWebhook> webhooks);
  public A withWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhook... webhooks);
  public Boolean hasWebhooks();
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhook();
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhookLike(MutatingWebhook item);
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> setNewWebhookLike(int index,MutatingWebhook item);
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> editWebhook(int index);
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> editFirstWebhook();
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> editLastWebhook();
  public MutatingWebhookConfigurationFluent.WebhooksNested<A> editMatchingWebhook(Predicate<MutatingWebhookBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<MutatingWebhookConfigurationFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface WebhooksNested<N> extends Nested<N>,MutatingWebhookFluent<MutatingWebhookConfigurationFluent.WebhooksNested<N>>{
    public N and();
    public N endWebhook();
    
  }
  
}
